@@ -7,7 +7,7 @@ use meta;
 use Module::Runtime qw/use_module/;
 use Types::Standard qw/Any Bool Str Int Num HashRef ArrayRef Object/;
 
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
 sub import {
 	my ($caller) = caller();
@@ -309,11 +309,11 @@ __END__
 
 =head1 NAME
 
-Quaint - The great new Quaint!
+Quaint - Unusual Object Orientation 
 
 =head1 VERSION
 
-Version 0.02
+Version 0.03
 
 =cut
 
